@@ -260,10 +260,6 @@
         <source>You must run this program with admin access.</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>version:</source>
-        <translation type="vanished">wersja:</translation>
-    </message>
     <message>
         <location filename="../service.cpp" line="116"/>
         <source>Could not find service description</source>
